@@ -5,24 +5,23 @@
  *
  * -------------------------------------------------------------------------
  *
- * IT++ - C++ library of mathematical, signal processing, speech processing,
- *        and communications classes and functions
+ * Copyright (C) 1995-2010  (see AUTHORS file for a list of contributors)
  *
- * Copyright (C) 1995-2008  (see AUTHORS file for a list of contributors)
+ * This file is part of IT++ - a C++ library of mathematical, signal
+ * processing, speech processing, and communications classes and functions.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * IT++ is free software: you can redistribute it and/or modify it under the
+ * terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * IT++ is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU General Public License along
+ * with IT++.  If not, see <http://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -86,7 +85,7 @@ bool exist(const std::string& name)
 
 bfstream_base::bfstream_base(endian e):
     switch_endianity(false),
-    native_endianity(check_big_endianness() ? b_endian : l_endian)
+    native_endianity(is_bigendian() ? b_endian : l_endian)
 {
   if (native_endianity != e)
     switch_endianity = true;
@@ -207,7 +206,7 @@ int bifstream::length() // in bytes
   seekg(0, ios::end);
   len = tellg();
   seekg(pos1);
-  return len;
+  return int(len);
 }
 
 bifstream& bifstream::operator>>(char& a)
@@ -324,7 +323,7 @@ int bfstream::length() // in bytes
   seekg(0, ios::end);
   len = tellg();
   seekg(pos1);
-  return len;
+  return int(len);
 }
 
 bfstream& bfstream::operator<<(char a)
