@@ -5,30 +5,35 @@
  *
  * -------------------------------------------------------------------------
  *
- * IT++ - C++ library of mathematical, signal processing, speech processing,
- *        and communications classes and functions
+ * Copyright (C) 1995-2010  (see AUTHORS file for a list of contributors)
  *
- * Copyright (C) 1995-2008  (see AUTHORS file for a list of contributors)
+ * This file is part of IT++ - a C++ library of mathematical, signal
+ * processing, speech processing, and communications classes and functions.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * IT++ is free software: you can redistribute it and/or modify it under the
+ * terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * IT++ is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU General Public License along
+ * with IT++.  If not, see <http://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
 
 #include <itpp/base/mat.h>
 
+#ifndef _MSC_VER
+#  include <itpp/config.h>
+#else
+#  include <itpp/config_msvc.h>
+#endif
+
 #if defined (HAVE_BLAS)
 #  include <itpp/base/blas.h>
 #endif
@@ -81,7 +86,58 @@ cmat& cmat::operator*=(const cmat &m)
   operator=(r); // time consuming
   return *this;
 }
+#else
+template<>
+mat& mat::operator*=(const mat &m)
+{
+  it_assert_debug(no_cols == m.no_rows, "Mat<>::operator*=(): Wrong sizes");
+  mat r(no_rows, m.no_cols);
+  int r_pos = 0, pos = 0, m_pos = 0;
 
+  for (int i = 0; i < r.no_cols; i++) {
+    for (int j = 0; j < r.no_rows; j++) {
+      double tmp = 0.0;
+      pos = 0;
+      for (int k = 0; k < no_cols; k++) {
+        tmp += data[pos+j] * m.data[m_pos+k];
+        pos += no_rows;
+      }
+      r.data[r_pos+j] = tmp;
+    }
+    r_pos += r.no_rows;
+    m_pos += m.no_rows;
+  }
+  operator=(r); // time consuming
+  return *this;
+}
+
+template<>
+cmat& cmat::operator*=(const cmat &m)
+{
+  it_assert_debug(no_cols == m.no_rows, "Mat<>::operator*=(): Wrong sizes");
+  cmat r(no_rows, m.no_cols);
+  int r_pos = 0, pos = 0, m_pos = 0;
+
+  for (int i = 0; i < r.no_cols; i++) {
+    for (int j = 0; j < r.no_rows; j++) {
+      std::complex<double> tmp(0.0);
+      pos = 0;
+      for (int k = 0; k < no_cols; k++) {
+        tmp += data[pos+j] * m.data[m_pos+k];
+        pos += no_rows;
+      }
+      r.data[r_pos+j] = tmp;
+    }
+    r_pos += r.no_rows;
+    m_pos += m.no_rows;
+  }
+  operator=(r); // time consuming
+  return *this;
+}
+#endif // HAVE_BLAS
+
+
+#if defined(HAVE_BLAS)
 template<>
 mat operator*(const mat &m1, const mat &m2)
 {
@@ -109,7 +165,60 @@ cmat operator*(const cmat &m1, const cmat &m2)
                &r.no_rows);
   return r;
 }
+#else
+template<>
+mat operator*(const mat &m1, const mat &m2)
+{
+  it_assert_debug(m1.no_cols == m2.no_rows,
+                  "Mat<>::operator*(): Wrong sizes");
+  mat r(m1.no_rows, m2.no_cols);
+  double *tr = r.data;
+  double *t1;
+  double *t2 = m2.data;
+  for (int i = 0; i < r.no_cols; i++) {
+    for (int j = 0; j < r.no_rows; j++) {
+      double tmp = 0.0;
+      t1 = m1.data + j;
+      for (int k = m1.no_cols; k > 0; k--) {
+        tmp += *(t1) * *(t2++);
+        t1 += m1.no_rows;
+      }
+      *(tr++) = tmp;
+      t2 -= m2.no_rows;
+    }
+    t2 += m2.no_rows;
+  }
+  return r;
+}
 
+template<>
+cmat operator*(const cmat &m1, const cmat &m2)
+{
+  it_assert_debug(m1.no_cols == m2.no_rows,
+                  "Mat<>::operator*(): Wrong sizes");
+  cmat r(m1.no_rows, m2.no_cols);
+  std::complex<double> *tr = r.data;
+  std::complex<double> *t1;
+  std::complex<double> *t2 = m2.data;
+  for (int i = 0; i < r.no_cols; i++) {
+    for (int j = 0; j < r.no_rows; j++) {
+      std::complex<double> tmp(0.0);
+      t1 = m1.data + j;
+      for (int k = m1.no_cols; k > 0; k--) {
+        tmp += *(t1) * *(t2++);
+        t1 += m1.no_rows;
+      }
+      *(tr++) = tmp;
+      t2 -= m2.no_rows;
+    }
+    t2 += m2.no_rows;
+  }
+  return r;
+}
+#endif // HAVE_BLAS
+
+
+#if defined(HAVE_BLAS)
 template<>
 vec operator*(const mat &m, const vec &v)
 {
@@ -137,7 +246,40 @@ cvec operator*(const cmat &m, const cvec &v)
                v._data(), &incr, &beta, r._data(), &incr);
   return r;
 }
+#else
+template<>
+vec operator*(const mat &m, const vec &v)
+{
+  it_assert_debug(m.no_cols == v.size(),
+                  "Mat<>::operator*(): Wrong sizes");
+  vec r(m.no_rows);
+  for (int i = 0; i < m.no_rows; i++) {
+    r(i) = 0.0;
+    int m_pos = 0;
+    for (int k = 0; k < m.no_cols; k++) {
+      r(i) += m.data[m_pos+i] * v(k);
+      m_pos += m.no_rows;
+    }
+  }
+  return r;
+}
 
+template<>
+cvec operator*(const cmat &m, const cvec &v)
+{
+  it_assert_debug(m.no_cols == v.size(),
+                  "Mat<>::operator*(): Wrong sizes");
+  cvec r(m.no_rows);
+  for (int i = 0; i < m.no_rows; i++) {
+    r(i) = std::complex<double>(0.0);
+    int m_pos = 0;
+    for (int k = 0; k < m.no_cols; k++) {
+      r(i) += m.data[m_pos+i] * v(k);
+      m_pos += m.no_rows;
+    }
+  }
+  return r;
+}
 #endif // HAVE_BLAS
 
 
@@ -203,29 +345,14 @@ template bmat operator-(const bmat &m);
 
 // multiplication operators
 
-#if !defined(HAVE_BLAS)
-template mat operator*(const mat &m1, const mat &m2);
-template cmat operator*(const cmat &m1, const cmat &m2);
-#endif
 template imat operator*(const imat &m1, const imat &m2);
 template smat operator*(const smat &m1, const smat &m2);
 template bmat operator*(const bmat &m1, const bmat &m2);
 
-#if !defined(HAVE_BLAS)
-template vec operator*(const mat &m, const vec &v);
-template cvec operator*(const cmat &m, const cvec &v);
-#endif
-
 template ivec operator*(const imat &m, const ivec &v);
 template svec operator*(const smat &m, const svec &v);
 template bvec operator*(const bmat &m, const bvec &v);
 
-template mat operator*(const vec &v, const mat &m);
-template cmat operator*(const cvec &v, const cmat &m);
-template imat operator*(const ivec &v, const imat &m);
-template smat operator*(const svec &v, const smat &m);
-template bmat operator*(const bvec &v, const bmat &m);
-
 template mat operator*(const mat &m, double t);
 template cmat operator*(const cmat &m, std::complex<double> t);
 template imat operator*(const imat &m, int t);
@@ -288,6 +415,12 @@ template bin elem_mult_sum(const bmat &m1, const bmat &m2);
 
 // division operator
 
+template mat operator/(double t, const mat &m);
+template cmat operator/(std::complex<double> t, const cmat &m);
+template imat operator/(int t, const imat &m);
+template smat operator/(short t, const smat &m);
+template bmat operator/(bin t, const bmat &m);
+
 template mat operator/(const mat &m, double t);
 template cmat operator/(const cmat &m, std::complex<double> t);
 template imat operator/(const imat &m, int t);
