@@ -5,24 +5,23 @@
  *
  * -------------------------------------------------------------------------
  *
- * IT++ - C++ library of mathematical, signal processing, speech processing,
- *        and communications classes and functions
+ * Copyright (C) 1995-2010  (see AUTHORS file for a list of contributors)
  *
- * Copyright (C) 1995-2008  (see AUTHORS file for a list of contributors)
+ * This file is part of IT++ - a C++ library of mathematical, signal
+ * processing, speech processing, and communications classes and functions.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * IT++ is free software: you can redistribute it and/or modify it under the
+ * terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * IT++ is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU General Public License along
+ * with IT++.  If not, see <http://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -30,47 +29,9 @@
 #ifndef TRIG_HYP_H
 #define TRIG_HYP_H
 
-#ifndef _MSC_VER
-#  include <itpp/config.h>
-#else
-#  include <itpp/config_msvc.h>
-#endif
-
 #include <itpp/base/help_functions.h>
 
 
-//! \addtogroup hypfunc
-//!@{
-
-#ifndef HAVE_ASINH
-//! Arcus sinhyp
-inline double asinh(double x)
-{
-  return ((x >= 0) ? log(x + sqrt(x * x + 1)) : -log(-x + sqrt(x * x + 1)));
-}
-#endif
-
-#ifndef HAVE_ACOSH
-//! Arcus coshyp
-inline double acosh(double x)
-{
-  it_error_if(x < 1, "acosh(): Argument must be greater then 1.");
-  return log(x + sqrt(x * x - 1.0));
-}
-#endif
-
-#ifndef HAVE_ATANH
-//! Arcus tanhyp
-inline double atanh(double x)
-{
-  it_error_if(fabs(x) >= 1, "atanh(): Argument out of range.");
-  return 0.5 * log((x + 1) / (x - 1));
-}
-#endif
-
-//!@}
-
-
 namespace itpp
 {
 
@@ -137,17 +98,17 @@ inline vec tanh(const vec &x) { return apply_function<double>(std::tanh, x); }
 //! Tan hyperbolic function
 inline mat tanh(const mat &x) { return apply_function<double>(std::tanh, x); }
 //! Inverse sine hyperbolic function
-inline vec asinh(const vec &x) { return apply_function<double>(::asinh, x); }
+vec asinh(const vec &x);
 //! Inverse sine hyperbolic function
-inline mat asinh(const mat &x) { return apply_function<double>(::asinh, x); }
+mat asinh(const mat &x);
 //! Inverse cosine hyperbolic function
-inline vec acosh(const vec &x) { return apply_function<double>(::acosh, x); }
+vec acosh(const vec &x);
 //! Inverse cosine hyperbolic function
-inline mat acosh(const mat &x) { return apply_function<double>(::acosh, x); }
+mat acosh(const mat &x);
 //! Inverse tan hyperbolic function
-inline vec atanh(const vec &x) { return apply_function<double>(::atanh, x); }
+vec atanh(const vec &x);
 //! Inverse tan hyperbolic function
-inline mat atanh(const mat &x) { return apply_function<double>(::atanh, x); }
+mat atanh(const mat &x);
 
 //!@}
 
