@@ -5,86 +5,53 @@
  *
  * -------------------------------------------------------------------------
  *
- * IT++ - C++ library of mathematical, signal processing, speech processing,
- *        and communications classes and functions
+ * Copyright (C) 1995-2010  (see AUTHORS file for a list of contributors)
  *
- * Copyright (C) 1995-2008  (see AUTHORS file for a list of contributors)
+ * This file is part of IT++ - a C++ library of mathematical, signal
+ * processing, speech processing, and communications classes and functions.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * IT++ is free software: you can redistribute it and/or modify it under the
+ * terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * IT++ is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU General Public License along
+ * with IT++.  If not, see <http://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
 
 #include <itpp/base/random.h>
+#include <itpp/base/itcompat.h>
 #include <itpp/base/math/elem_math.h>
-#include <limits>
 
 
 namespace itpp
 {
 
-///////////////////////////////////////////////
-// Random_Generator
-///////////////////////////////////////////////
+// ----------------------------------------------------------------------
+// Random_Generator (DSFMT_19937_RNG)
+// ----------------------------------------------------------------------
 
+template <>
 bool Random_Generator::initialized = false;
-int Random_Generator::left = 0;
-unsigned int Random_Generator::state[624];
-unsigned int *Random_Generator::pNext;
-
-unsigned int Random_Generator::hash(time_t t, clock_t c)
-{
-  // Get a unsigned int from t and c
-  // Better than uint(x) in case x is floating point in [0,1]
-  // Based on code by Lawrence Kirby (fred@genesis.demon.co.uk)
-  static unsigned int differ = 0; // guarantee time-based seeds will change
-
-  unsigned int h1 = 0;
-  unsigned char *p = (unsigned char *) & t;
-  for (size_t i = 0; i < sizeof(t); ++i) {
-    h1 *= std::numeric_limits<unsigned char>::max() + 2U;
-    h1 += p[i];
-  }
-  unsigned int h2 = 0;
-  p = (unsigned char *) & c;
-  for (size_t j = 0; j < sizeof(c); ++j) {
-    h2 *= std::numeric_limits<unsigned char>::max() + 2U;
-    h2 += p[j];
-  }
-  return (h1 + differ++) ^ h2;
-}
-
-void Random_Generator::get_state(ivec &out_state)
-{
-  out_state.set_size(625, false);
-  for (int i = 0; i < 624; i++)
-    out_state(i) = state[i];
-
-  out_state(624) = left; // the number of elements left in state before reload
-}
-
-void Random_Generator::set_state(ivec &new_state)
-{
-  it_assert(new_state.size() == 625, "Random_Generator::set_state(): Not a valid state vector");
-
-  for (int i = 0; i < 624; i++)
-    state[i] = new_state(i);
-
-  left = new_state(624);
-  pNext = &state[624-left];
-}
+template <>
+bool Random_Generator::bigendian = is_bigendian();
+template <>
+Random_Generator::w128_t Random_Generator::status[N + 1] = { };
+template <>
+int Random_Generator::idx = 0;
+template <>
+unsigned int Random_Generator::last_seed = 0U;
+#if defined(__SSE2__)
+template <>
+__m128i Random_Generator::sse2_param_mask = _mm_set_epi32(0, 0, 0, 0);
+#endif // __SSE2__
 
 
 // Set the seed of the Global Random Number Generator
@@ -112,11 +79,11 @@ void RNG_randomize()
 void RNG_get_state(ivec &state)
 {
   Random_Generator RNG;
-  RNG.get_state(state);
+  state = RNG.get_state();
 }
 
 // Resume the state saved in memory
-void RNG_set_state(ivec &state)
+void RNG_set_state(const ivec &state)
 {
   Random_Generator RNG;
   RNG.set_state(state);
@@ -229,6 +196,185 @@ mat Exponential_RNG::operator()(int h, int w)
   return mm;
 }
 
+///////////////////////////////////////////////
+// Gamma_RNG
+///////////////////////////////////////////////
+
+vec Gamma_RNG::operator()(int n)
+{
+  vec vv(n);
+  for (int i = 0; i < n; i++)
+    vv(i) = sample();
+  return vv;
+}
+
+mat Gamma_RNG::operator()(int r, int c)
+{
+  mat mm(r, c);
+  for (int i = 0; i < r * c; i++)
+    mm(i) = sample();
+  return mm;
+}
+
+double Gamma_RNG::sample()
+{
+  // A copy of rgamma code from the R package, adapted to IT++ by Vasek
+  // Smidl
+
+  /* Constants : */
+  const static double sqrt32 = 5.656854;
+  const static double exp_m1 = 0.36787944117144232159;/* exp(-1) = 1/e */
+
+  const static double q1 = 0.04166669;
+  const static double q2 = 0.02083148;
+  const static double q3 = 0.00801191;
+  const static double q4 = 0.00144121;
+  const static double q5 = -7.388e-5;
+  const static double q6 = 2.4511e-4;
+  const static double q7 = 2.424e-4;
+
+  const static double a1 = 0.3333333;
+  const static double a2 = -0.250003;
+  const static double a3 = 0.2000062;
+  const static double a4 = -0.1662921;
+  const static double a5 = 0.1423657;
+  const static double a6 = -0.1367177;
+  const static double a7 = 0.1233795;
+
+  /* State variables [FIXME for threading!] :*/
+  static double aa = 0.;
+  static double aaa = 0.;
+  static double s, s2, d;    /* no. 1 (step 1) */
+  static double q0, b, si, c;/* no. 2 (step 4) */
+
+  double e, p, q, r, t, u, v, w, x, ret_val;
+  double a = alpha;
+  double scale = 1.0 / beta;
+
+  it_error_if(!std::isfinite(a) || !std::isfinite(scale) || (a < 0.0)
+              || (scale <= 0.0), "Gamma_RNG wrong parameters");
+
+  if (a < 1.) { /* GS algorithm for parameters a < 1 */
+    if (a == 0)
+      return 0.;
+    e = 1.0 + exp_m1 * a;
+    for (;;) { //VS repeat
+      p = e * RNG.genrand_open_open();
+      if (p >= 1.0) {
+        x = -std::log((e - p) / a);
+        if (-std::log(RNG.genrand_open_close()) >= (1.0 - a) * std::log(x))
+          break;
+      }
+      else {
+        x = std::exp(std::log(p) / a);
+        if (-std::log(RNG.genrand_open_close()) >= x)
+          break;
+      }
+    }
+    return scale * x;
+  }
+
+  /* --- a >= 1 : GD algorithm --- */
+
+  /* Step 1: Recalculations of s2, s, d if a has changed */
+  if (a != aa) {
+    aa = a;
+    s2 = a - 0.5;
+    s = std::sqrt(s2);
+    d = sqrt32 - s * 12.0;
+  }
+  /* Step 2: t = standard normal deviate, x = (s,1/2) -normal deviate. */
+  /* immediate acceptance (i) */
+  t = NRNG.sample();
+  x = s + 0.5 * t;
+  ret_val = x * x;
+  if (t >= 0.0)
+    return scale * ret_val;
+
+  /* Step 3: u = 0,1 - uniform sample. squeeze acceptance (s) */
+  u = RNG.genrand_close_open();
+  if ((d * u) <= (t * t * t))
+    return scale * ret_val;
+
+  /* Step 4: recalculations of q0, b, si, c if necessary */
+  if (a != aaa) {
+    aaa = a;
+    r = 1.0 / a;
+    q0 = ((((((q7 * r + q6) * r + q5) * r + q4) * r + q3) * r
+           + q2) * r + q1) * r;
+
+    /* Approximation depending on size of parameter a */
+    /* The constants in the expressions for b, si and c */
+    /* were established by numerical experiments */
+    if (a <= 3.686) {
+      b = 0.463 + s + 0.178 * s2;
+      si = 1.235;
+      c = 0.195 / s - 0.079 + 0.16 * s;
+    }
+    else if (a <= 13.022) {
+      b = 1.654 + 0.0076 * s2;
+      si = 1.68 / s + 0.275;
+      c = 0.062 / s + 0.024;
+    }
+    else {
+      b = 1.77;
+      si = 0.75;
+      c = 0.1515 / s;
+    }
+  }
+
+  /* Step 5: no quotient test if x not positive */
+  if (x > 0.0) {
+    /* Step 6: calculation of v and quotient q */
+    v = t / (s + s);
+    if (std::fabs(v) <= 0.25)
+      q = q0 + 0.5 * t * t * ((((((a7 * v + a6) * v + a5) * v + a4) * v
+                                + a3) * v + a2) * v + a1) * v;
+    else
+      q = q0 - s * t + 0.25 * t * t + (s2 + s2) * log(1.0 + v);
+
+    /* Step 7: quotient acceptance (q) */
+    if (log(1.0 - u) <= q)
+      return scale * ret_val;
+  }
+
+  for (;;) { //VS repeat
+    /* Step 8: e = standard exponential deviate
+     *         u =  0,1 -uniform deviate
+     *         t = (b,si)-double exponential (laplace) sample */
+    e = -std::log(RNG.genrand_open_close()); //see Exponential_RNG
+    u = RNG.genrand_open_close();
+    u = u + u - 1.0;
+    if (u < 0.0)
+      t = b - si * e;
+    else
+      t = b + si * e;
+    /* Step 9: rejection if t < tau(1) = -0.71874483771719 */
+    if (t >= -0.71874483771719) {
+      /* Step 10:  calculation of v and quotient q */
+      v = t / (s + s);
+      if (std::fabs(v) <= 0.25)
+        q = q0 + 0.5 * t * t *
+            ((((((a7 * v + a6) * v + a5) * v + a4) * v + a3) * v
+              + a2) * v + a1) * v;
+      else
+        q = q0 - s * t + 0.25 * t * t + (s2 + s2) * log(1.0 + v);
+      /* Step 11: hat acceptance (h) */
+      /* (if q not positive go to step 8) */
+      if (q > 0.0) {
+        // Try to use w = expm1(q); (Not supported on w32)
+        w = expm1(q);
+        /*  ^^^^^ original code had approximation with rel.err < 2e-7 */
+        /* if t is rejected sample again at step 8 */
+        if ((c * std::fabs(u)) <= (w * std::exp(e - 0.5 * t * t)))
+          break;
+      }
+    }
+  } /* repeat .. until `t' is accepted */
+  x = s + 0.5 * t;
+  return scale * x * x;
+}
+
 ///////////////////////////////////////////////
 // Normal_RNG
 ///////////////////////////////////////////////
@@ -356,14 +502,14 @@ const double Normal_RNG::PARAM_R = 3.44428647676;
 // Get a Normal distributed (0,1) sample
 double Normal_RNG::sample()
 {
-  unsigned int u, sign, i, j;
+  uint32_t u, sign, i, j;
   double x, y;
 
   while (true) {
-    u = RNG.random_int();
-    sign = u & 0x80; // 1 bit for the sign
-    i = u & 0x7f; // 7 bits to choose the step
-    j = u >> 8; // 24 bits for the x-value
+    u = RNG.genrand_uint32();
+    sign = u & 0x80;            // 1 bit for the sign
+    i = u & 0x7f;               // 7 bits to choose the step
+    j = u >> 8;                 // 24 bits for the x-value
 
     x = j * wtab[i];
 
@@ -371,11 +517,11 @@ double Normal_RNG::sample()
       break;
 
     if (i < 127) {
-      y = ytab[i+1] + (ytab[i] - ytab[i+1]) * RNG.random_01();
+      y = ytab[i+1] + (ytab[i] - ytab[i+1]) * RNG.genrand_close_open();
     }
     else {
-      x = PARAM_R - std::log(1.0 - RNG.random_01()) / PARAM_R;
-      y = std::exp(-PARAM_R * (x - 0.5 * PARAM_R)) * RNG.random_01();
+      x = PARAM_R - std::log(1.0 - RNG.genrand_close_open()) / PARAM_R;
+      y = std::exp(-PARAM_R * (x - 0.5 * PARAM_R)) * RNG.genrand_close_open();
     }
 
     if (y < std::exp(-0.5 * x * x))
