@@ -1,28 +1,27 @@
 /*!
  * \file
  * \brief Implementation of Low-Density Parity Check (LDPC) codes
- * \author Erik G. Larsson, Mattias Andersson and Adam Piatyszek
+ * \author Erik G. Larsson, Mattias Andersson, Adam Piatyszek and Gorka Prieto 
  *
  * -------------------------------------------------------------------------
  *
- * IT++ - C++ library of mathematical, signal processing, speech processing,
- *        and communications classes and functions
+ * Copyright (C) 1995-2010  (see AUTHORS file for a list of contributors)
  *
- * Copyright (C) 1995-2008  (see AUTHORS file for a list of contributors)
+ * This file is part of IT++ - a C++ library of mathematical, signal
+ * processing, speech processing, and communications classes and functions.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * IT++ is free software: you can redistribute it and/or modify it under the
+ * terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * IT++ is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU General Public License along
+ * with IT++.  If not, see <http://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -717,8 +716,11 @@ protected:
 
   \note Please refer to the tutorials \ref ldpc_gen_codes and \ref
   ldpc_bersim_awgn for extensive examples of how to use LDPC codes.
-
-  \author Erik G. Larsson and Adam Piatyszek
+ 
+  \note For issues relating to the accuracy of LLR computations,
+  please see the documentation of \c LLR_calc_unit
+  
+  \author Erik G. Larsson, Adam Piatyszek and Gorka Prieto (decoder improvements)
 */
 class LDPC_Code : public Channel_Code
 {
@@ -899,6 +901,9 @@ public:
   //! Get the number of check nodes
   int get_ncheck() const { return ncheck; }
 
+  //! Get the number of information bits per codeword
+  int get_ninfo() const { return nvar - ncheck; }
+
   //! Return the decoding method
   std::string get_decoding_method() const { return dec_method; }
 
@@ -940,6 +945,9 @@ private:
 
   // temporary storage for decoder (memory allocated when codec defined)
   QLLRvec mvc, mcv;
+
+  //! Maximum check node degree that the class can handle
+  static const int max_cnd = 200;
 };
 
 
