@@ -5,24 +5,23 @@
  *
  * -------------------------------------------------------------------------
  *
- * IT++ - C++ library of mathematical, signal processing, speech processing,
- *        and communications classes and functions
+ * Copyright (C) 1995-2010  (see AUTHORS file for a list of contributors)
  *
- * Copyright (C) 1995-2008  (see AUTHORS file for a list of contributors)
+ * This file is part of IT++ - a C++ library of mathematical, signal
+ * processing, speech processing, and communications classes and functions.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * IT++ is free software: you can redistribute it and/or modify it under the
+ * terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any
+ * later version.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * IT++ is distributed in the hope that it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
+ * details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+ * You should have received a copy of the GNU General Public License along
+ * with IT++.  If not, see <http://www.gnu.org/licenses/>.
  *
  * -------------------------------------------------------------------------
  */
@@ -64,14 +63,23 @@ const QLLR QLLR_MAX = (std::numeric_limits<QLLR>::max() >> 4);
 /*!
   \brief Log-likelihood algebra calculation unit.
 
-  This class contains functions for algebra with log-likelihood
-  ratios (LLRs). The (sole) purpose of this class is to provide
-  numerically efficient functions for turbo and LDPC codes, which
-  rely on certain nonlinear operations on LLRs.
-
-  An LLR for an information bit b is defined according to \f[ L =
-  \log \frac{P(b=0)}{P(b=1)} \f] and it is in general a real number.
+  This class contains functions for algebra with log-likelihood ratios
+  (LLRs). The class is mainly useful for modules that rely on certain
+  nonlinear operations on LLRs (e.g. boxplus for LDPC and turbo
+  decoding and Jacobian logarithm for soft demodulation). The routines
+  provided are numerically efficient and use only integer
+  arithmetics. Additionally, they allow for arbitrary quantization of
+  LLRs in order to study effects of limited precision (fixed point
+  number representations). As a consequence, computations are
+  approximate. With the standard settings, the numerical precision
+  should be sufficient (and practically equivalent to floating point
+  precision) for all practical applications.  However, one can
+  construct cases where small numerical artifacts due to quantization
+  effects (e.g., soft demodulation with very high or very low SNR) can
+  be observed.
 
+  An LLR for an information bit b is defined according to \f[ L = \log
+  \frac{P(b=0)}{P(b=1)} \f] and it is in general a real number.
   LLR values are represented via the special type, "quantized
   LLR" (QLLR).  The relation between the quantized representation
   and the real (floating-point) LLR value is
